
.. _TutosPhotoWebSite:

Building a photo gallery with |cubicweb|
========================================

Desired features
----------------

* basically a photo gallery

* photo stored on the file system and displayed dynamically through a web interface

* navigation through folder (album), tags, geographical zone, people on the
  picture... using facets

* advanced security (not everyone can see everything). More on this later.


.. toctree::
   :maxdepth: 2

   part01_create-cube
   part02_security
   part03_bfss
   part04_ui-base
   part05_ui-advanced


